# Generated by Django 4.2.7 on 2023-12-01 15:47

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_next_appointment", "0004_alter_infosources_display_index_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="infosources",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AddIndex(
            model_name="infosources",
            index=models.Index(fields=["name"], name="edc_next_ap_name_543d65_idx"),
        ),
    ]



# Generated by Django 4.2.7 on 2023-12-01 15:45

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "edc_next_appointment",
            "0003_remove_infosources_edc_next_ap_id_0fdae6_idx_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="infosources",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="infosources",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
    ]



# Generated by Django 4.2.7 on 2023-12-01 23:07

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("edc_next_appointment", "0005_alter_infosources_name_and_more"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="infosources",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Information Source",
                "verbose_name_plural": "Information Sources",
            },
        ),
    ]



# Generated by Django 4.2.7 on 2023-12-04 22:19

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("edc_next_appointment", "0006_alter_infosources_options"),
    ]

    operations = [
        migrations.RemoveIndex(
            model_name="infosources",
            name="edc_next_ap_name_543d65_idx",
        ),
    ]



# Generated by Django 4.2.7 on 2023-12-01 15:40

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_next_appointment", "0002_infosources_extra_value"),
    ]

    operations = [
        migrations.RemoveIndex(
            model_name="infosources",
            name="edc_next_ap_id_0fdae6_idx",
        ),
        migrations.AddIndex(
            model_name="infosources",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="edc_next_ap_display_4e292d_idx",
            ),
        ),
    ]
